%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                       %
%   In this M-file one can introduce parameters into the model,         %
%   and set the initial conditions and the simulation time.             %
%                                                                       %
%                                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %                                                           %
    %                                                           %
    %         Mebrane complexes                                 %
    %                                                           %  
    %         y(1)   pMHC1   free                               %    
    %         y(2)   TCR|pMHC1                                  %
    %         y(3)   LCK|TCR|pMHC1                              %
    %         y(4)   LCKs|TCR|pMHC1                             %
    %         y(5)   LCKy|TCR|pMHC1                             %
    %         y(6)   LCKsy|TCR|pMHC1                            %
    %         y(7)   LCKy|pTCR|pMHC1                            %
    %         y(8)   LCKsy|pTCR|pMHC1                           %
    %         y(9)   LCKy|ppTCR|pMHC1                           %
    %         y(10)  LCKsy|ppTCR|pMHC1                          %
    %                                                           %
    %         y(11)   pMHC2  free                               %    
    %         y(12)   TCR|pMHC2                                 %
    %         y(13)   LCK|TCR|pMHC2                             %
    %         y(14)   LCKs|TCR|pMHC2                            %
    %         y(15)   LCKy|TCR|pMHC2                            %
    %         y(16)   LCKsy|TCR|pMHC2                           %
    %         y(17)   LCKy|pTCR|pMHC2                           %
    %         y(18)   LCKsy|pTCR|pMHC2                          %
    %         y(19)   LCKy|ppTCR|pMHC2                          %
    %         y(20)   LCKsy|ppTCR|pMHC2                         %
    %                                                           %
    %         y(21)  TCR free                                   %
    %                                                           % 
    %         y(22)       pSHP|TCR                              %
    %         y(23)       pSHP|TCR|pMHC1                        % 
    %         y(24)       pSHP|LCK|TCR|pMHC1 complex            %
    %         y(25)       pSHP|TCR|pMHC2                        %
    %         y(26)       pSHP|LCK|TCR|pMHC2                    %
    %                                                           %
    %         Cytosolic proteins                                %
    %                                                           %
    %         y(27)   LCK                                       %
    %         y(28)   SHP free                                  %
    %         y(29)   pSHP free                                 %
    %         y(30)   ZAP                                       %
    %         y(31)   ZAPp                                      %
    %         y(32)   MEK                                       %
    %         y(33)   pMEK                                      %
    %         y(34)   ppMEK                                     %
    %         y(35)   ERK                                       %
    %         y(36)   pERK                                      %
    %         y(37)   ppERK                                     %
    %                                                           %
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%############## Simulation time points ##################################
%########################################################################


t0=1000;             % equlibration time (at time t0 one may add new peptides)
tw=1000;             % length of simulation from adding new peptides
ttot=t0+tw;         % total simulation time in seconds


%########################################################################
%########################################################################

%############### Initial conditions  ####################################
%########################################################################

NC=37;    % number of substrates (ODEs)
y0=zeros(1,NC);  


%%%%  change this initial conditions to test bistability of the system %%%%
%%%%  the below values are from simulation with no peptide stimulation %%%% 

y0(10)=0;               %LCKsy|ppTCR|pMHC1
y0(20)=0;               %LCKsy|ppTCR|pMHC2
y0(31)=10;              %pZAP 
y0(33)=4760;            %4760 pMEK 
y0(34)=60;              %60 ppMEK 
y0(36)=27000;           %27000 pERK
y0(37)=670;             %670  ppERK   
y0(29)=500;             %500 pSHP free
y0(22)=4400;            %4400 TCR|pSHP 



%%%%%%%%% Fixed initial conditions %%%%%%%%%%%%

pMHC1=100;  % number of agonist peptide MHC added at t=0
pMHC11=0;   % number of agonist peptide MHC added at time t0
pMHC2=0;    % number of endogenous or antagonist peptide MHC added at t=0
pMHC22=300; % number of endogenous or antagonist peptide MHC added at time t0

% You can set pMHC1=0, pMHC11=100, pMHC2=300, pMHC22=0, i.e. add antagonist
% peptides first to test the bistability of the system % 

TCR=30000;
LCK=100000;
ZAP=100000;
MEK=100000;
ERK=300000;
SHP=300000; 



y0(21)=TCR-y0(22);
y0(27)=LCK;
y0(28)=SHP-y0(29)-y0(22);
y0(30)=ZAP-y0(31);
y0(32)=MEK-y0(33)-y0(34);
y0(35)=ERK-y0(36)-y0(37);


%############### Parametrization for system of ODE's ####################
%########################################################################

%XXXXXXXXXXXXXXXXX Complex  XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX                                 

 b1=0.3/TCR;                 %0.3/TCR  agonist peptide binding 
 b2=b1;                      %antagonist peptide binding 

 
 d1=0.05;                      %0.05 agonist  peptide disociation
 d2=0.333;                     %0.333 antagonist or endogenous peptide disociation
 
 lb=0.3/LCK;                %0.3/LCK%  LCk(s)  binding
 
 ly2=0.3;                   %0.3%    LCK(s) ->LCK(s)y  theorine phosporylation at complex
 ly1=5/SHP;                 %5/SHP  pSHP complex binding
 
 
 ls2=0.5/ERK;               %0.5/ERK         LCK(y) ->LCK s(y)     ppERK catalyzed serine phosphorylation
 ls1=0.1;                   %0.1             LCK (y)s ->LCK (y)    "spontaneuos" serine dephosphorylation
 
 tp=0.05;                   %0.05            TCR ->pTCR and pTCR->ppTCR 
 
 %XXXXXXXXXXXXXXXXXXX Cytosolic Proteins XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
 
 s0=10^(-5);                  %10^(-5)   SHP -> pSHP              SHP spontaneous phosphorylation
 s1=30/SHP;                   %30/SHP    SHP -> pSHP              SHP phosphorylation
 s2=0.0006;                   %0.0006    pSHP -> SHP              SHP dephosphorylation (results in immediate dissociation)
 s3=0.05;                     %0.05%                              SHP dissociation
 
 z0=2*10^(-6);                %2*10^(-6)   ZAP -> pZAP            ZAP spontaneous phosphorylation 
 z1=5/ZAP;                    %5/ZAP       ZAP -> pZAP            ZAP phosphorylation (catalyzed by ppTCR)
 z2=0.02;                     %0.02        pZAP -> ZAP            ZAP dephosphorylation 
 
 m1=5/MEK;                   %5/MEK    MEK -> pMEK and pMEK -> ppMEK           MEK phosphorylation (catalyzed by pZAP)
 m2=0.02;                    %0.02     ppMEK -> pMEK and pMEK -> MEK           MEK dephosphorylation
 
 e1=5/ERK;                   %5/ERK    ERK -> pERK and pERK -> ppERK           ERK phosphorylation (catalyzed by ppMEK)
 e2=0.02;                    %0.02     ppERK -> pERK  and pERK -> ERK          ERK dephosphorylation
 
 
  
 %#########################################################################
 %#########################################################################