%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                      %
%   Code for solving deterministic (ODE) algorithm for TCR system      %
%   described in T. Lipniacki, B. Hat, J.R. Faeder, W.S. Hlavacek      %
%   Stochastic effects and bistability in T cell receptor signaling    %
%   J. Theor. Biol. 2008 doi 10.1016/j.jtbi.2008.05.001                %
%                                                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameters;            % parametrization of ODE's and simulation times

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%  STEP 1   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

tspan1=[0,t0]; 


y0(1)=pMHC1;
y0(11)=pMHC2;

[T1,Y1]=ode23tb(@model,tspan1,y0,[],TR); 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%  STEP 2   New peptide  added %%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


x=size(Y1);
y02=Y1(x(1),:); 



y02(1)=y02(1)+pMHC11;
y02(11)=y02(11)+pMHC22;

tspan2=[t0,ttot];         
[T2,Y2]=ode23tb(@model,tspan2,y02,[],TR); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T=[T1;T2];
Y=[Y1;Y2];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  FIGURES  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
set(gcf,'Color',[1,1,1])
subplot(2,3,1);
plot(T,Y(:,1));
grid on;
title('pMHC1 free');

subplot(2,3,2);
plot(T,Y(:,2));
grid on;
title('TCR|pMHC1');

subplot(2,3,3);
plot(T,Y(:,3));
grid on;
title('LCK|TCR|pMHC1');

subplot(2,3,4);
plot(T,Y(:,4));
grid on;
title('LCKs|TCR|pMHC1');

subplot(2,3,5);
plot(T,Y(:,23));
grid on;
title('pSHP|TCR|pMHC1');

subplot(2,3,6);
plot(T,Y(:,24));
grid on;
title('pSHP|TCR|LCK|pMHC1');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



figure(2)
set(gcf,'Color',[1,1,1])

subplot(2,3,1);
plot(T,Y(:,5));
grid on;
title('LCKy|TCR|pMHC1');

subplot(2,3,2);
plot(T,Y(:,6));
grid on;
title('LCKsy|TCR|pMHC1');

subplot(2,3,3);
plot(T,Y(:,7));
grid on;
title('LCKy|pTCR|pMHC1');

subplot(2,3,4);
plot(T,Y(:,8));
grid on;
title('LCKsy|pTCR|pMHC1');

subplot(2,3,5);
plot(T,Y(:,9));
grid on;
title('LCKy|ppTCR|pMHC1');

subplot(2,3,6);
plot(T,Y(:,10));
grid on;
title('LCKsy|ppTCR|pMHC1');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5555


figure(3)
set(gcf,'Color',[1,1,1])

subplot(2,3,1);
plot(T,SHP-Y(:,28));
grid on;
title('pSHP total');

subplot(2,3,2);
plot(T,Y(:,22));
grid on;
title(' pSHP|TCR');

subplot(2,3,3);
plot(T,Y(:,29));
grid on;
title(' pSHP free');

subplot(2,3,4);
plot(T,Y(:,31));
grid on;
title('pZAP');

subplot(2,3,5);
plot(T,Y(:,34));
grid on;
title('ppMEK');

subplot(2,3,6);
plot(T,Y(:,37));
grid on;
title('ppERK');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(4)
set(gcf,'Color',[1,1,1])

subplot(2,2,1);
plot(T,Y(:,21));
grid on;
title(' TCR');

subplot(2,2,2);
plot(T,Y(:,27));
grid on;
title(' LCK free');

subplot(2,2,3);
plot(T,Y(:,22));
grid on;
title('pSHP|TCR');

subplot(2,2,4);
plot(T,Y(:,2));
grid on;
title('TCR|pMHC1');

subplot(2,2,4);
plot(T,Y(:,12));
grid on;
title('TCR|pMHC2');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(5)
set(gcf,'Color',[1,1,1])

subplot(2,3,1);
plot(T,Y(:,11));
grid on;
title(' pMHC2 free');

subplot(2,3,2);
plot(T,Y(:,12));
grid on;
title('[B],   TCR|pMHC2');

subplot(2,3,3);
plot(T,Y(:,13));
grid on;
title(' LCK|TCR|pMHC2');

subplot(2,3,4);
plot(T,Y(:,14));
grid on;
title('  LCKs|TCR|pMHC2');

subplot(2,3,5);
plot(T,Y(:,25));
grid on;
title(' pSHP|TCR|pMHC2');


subplot(2,3,6);
plot(T,Y(:,26));
grid on;
title(' pSHP|TCR|LCK|pMHC2');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(6)
set(gcf,'Color',[1,1,1])

subplot(2,3,1);
plot(T,Y(:,15));
grid on;
title('LCKy|TCR|pMHC2');

subplot(2,3,2);
plot(T,Y(:,16));
grid on;
title('LCKsy|TCR|pMHC2');

subplot(2,3,3);
plot(T,Y(:,17));
grid on;
title('LCKy|pTCR|pMHC2');

subplot(2,3,4);
plot(T,Y(:,18));
grid on;
title('LCKsy|pTCR|pMHC2');

subplot(2,3,5);
plot(T,Y(:,19));
grid on;
title('LCKy|ppTCR|pMHC2');

subplot(2,3,6);
plot(T,Y(:,20));
grid on;
title('LCKsy|ppTCR|pMHC2');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
